@@ -2,7 +2,6 @@ import platform
 from time import sleep
 
 import pytest
-from pkg_resources import parse_version as v
 
 from qbittorrentapi import Conflict409Error
 from qbittorrentapi import TorrentDictionary
@@ -12,6 +11,7 @@ from qbittorrentapi import TorrentPropertiesDictionary
 from qbittorrentapi import TorrentStates
 from qbittorrentapi import TrackersList
 from qbittorrentapi import WebSeedsList
+from qbittorrentapi._version_support import v
 from tests.conftest import get_func
 from tests.test_torrents import check
 from tests.test_torrents import disable_queueing
@@ -426,6 +426,14 @@ def test_rename_folder(api_version, app_version, new_torrent, client_func, name)
             get_func(new_torrent, client_func)(old_path="", new_path="")
 
 
+def test_export(api_version, orig_torrent):
+    if v(api_version) >= v("2.8.14"):
+        assert isinstance(orig_torrent.export(), bytes)
+    else:
+        with pytest.raises(NotImplementedError):
+            orig_torrent.export()
+
+
 @pytest.mark.parametrize("client_func", ("piece_states", "pieceStates"))
 def test_piece_states(orig_torrent, client_func):
     assert isinstance(get_func(orig_torrent, client_func), TorrentPieceInfoList)
